***************************
* File: c_enseignants.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\First Round\ecole_1er_jour\c_enseignants.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "c_enseignants", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "c_enseignants", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen ID=concat(  codecole cod_ensgt)
destring ID, replace
order codecole cod_ensgt ID
label var ID "identifiant unique"

**************************************************
***   Recode missing values
***************************************************
*    DECODE MISSING VALUES
# d ;
qui mvdecode  fich_pres , mv(
4=.d);
qui mvdecode   rsn_abs, mv(
11=.d);
qui mvdecode   abs_auto, mv(
6=.d);
qui mvdecode   doc_abs, mv(
7=.d);
qui mvdecode    jour_abs abs_rest, mv(
999=.d);
# d cr;

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 


gen error01   = ( present == 2 & fich_pres< . )

foreach v of varlist   fonct_off  malade jour_mal heure1 min1 heure2 min2 abs_auto  doc_abs abs_n_auto {
	gen error02`v' = (  rsn_abs== 1 & `v'< . )
}


foreach v of varlist  typ_mission malade jour_mal heure1 min1 heure2 min2 abs_auto  doc_abs abs_n_auto {
	gen error03`v' = (rsn_abs== 2 & `v'< . )
}

foreach v of varlist    typ_mission fonct_off   heure1 min1 heure2 min2 abs_auto  doc_abs  abs_n_auto{
	gen error04`v' = (rsn_abs== 4 & `v'< . )
}

foreach v of varlist  typ_mission fonct_off  malade jour_mal abs_auto  doc_abs  abs_n_auto{
	gen error05`v' = (rsn_abs== 5 & `v'< . )
}

foreach v of varlist typ_mission fonct_off  malade jour_mal heure1 min1 heure2 min2  abs_n_auto{
	gen error06`v' = (rsn_abs== 6 & `v'< . )
}




**************************************************
***  Identify illegal responses
**************************************************
log using "c_enseignants label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
grubbs transfere jour_mal heure1 min1 heure2 min2 jour_abs abs_rest, level(99.99)

drop error* grubbs*
**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\ecole_1er_jour"
log using "c_enseignants codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\ecole_1er_jour"
save "c_enseignants_cleaned_data.dta", replace
